@@ -1,8 +1,9 @@
-/* apt-sourceslist.cpp - access the sources.list file
+/* apt-sourceslist.cpp - read & write APT repository sources
  *
  * Copyright (c) 1999 Patrick Cole <z@amused.net>
  *           (c) 2002 Synaptic development team
  *           (c) 2016 Daniel Nicoletti <dantti12@gmail.com>
+ *           (c) 2018-2025 Matthias Klumpp <matthias@tenstral.net>
  *
  * Author: Patrick Cole <z@amused.net>
  *         Michael Vogt <mvo@debian.org>
@@ -34,13 +35,27 @@
 #include <apt-pkg/sourcelist.h>
 #include <apt-pkg/strutl.h>
 #include <apt-pkg/error.h>
+#include <apt-pkg/tagfile.h>
+#include <filesystem>
 #include <algorithm>
 #include <fstream>
+#include <fcntl.h>
 
+#include "deb822.h"
 #include "apt-utils.h"
 
 #include "config.h"
 
+static std::vector<std::string> FindMultiValue(pkgTagSection &Tags, char const *const Field)
+{
+   auto values = Tags.FindS(Field);
+   // we ignore duplicate spaces by removing empty values
+   std::replace_if(values.begin(), values.end(), isspace_ascii, ' ');
+   auto vect = VectorizeString(values, ' ');
+   vect.erase(std::remove_if(vect.begin(), vect.end(), [](std::string const &s) { return s.empty(); }), vect.end());
+   return vect;
+}
+
 SourcesList::~SourcesList()
 {
     for (SourceRecord *sr : SourceRecords) {
@@ -61,9 +76,117 @@ SourcesList::SourceRecord *SourcesList::AddSourceNode(SourceRecord &rec)
     return newrec;
 }
 
-bool SourcesList::ReadSourcePart(string listpath)
+bool SourcesList::OpenConfigurationFileFd(std::string const &File, FileFd &Fd) /*{{{*/
+{
+   int const fd = open(File.c_str(), O_RDONLY | O_CLOEXEC | O_NOCTTY);
+   if (fd == -1)
+      return _error->WarningE("open", "Unable to read %s", File.c_str());
+   APT::Configuration::Compressor none(".", "", "", nullptr, nullptr, 0);
+   if (Fd.OpenDescriptor(fd, FileFd::ReadOnly, none, true) == false)
+      return false;
+   Fd.SetFileName(File);
+   return true;
+}
+
+bool SourcesList::ParseDeb822Stanza(const char *Type,
+                              pkgTagSection &Tags,
+                              unsigned int const stanzaIdx,
+                              FileFd &Fd)
+{
+    string Enabled = Tags.FindS("Enabled");
+
+    // now create one item per suite/section
+    auto const list_uris = FindMultiValue(Tags, "URIs");
+    auto const list_comp = FindMultiValue(Tags, "Components");
+    auto list_suite = FindMultiValue(Tags, "Suites");
+
+    {
+        auto const nativeArch = _config->Find("APT::Architecture");
+        std::transform(list_suite.begin(), list_suite.end(), list_suite.begin(),
+                       [&](std::string const &suite) { return SubstVar(suite, "$(ARCH)", nativeArch); });
+    }
+
+    if (list_uris.empty())
+        return _error->Error("Malformed entry %u in %s file %s (%s)", stanzaIdx, "sources", Fd.Name().c_str(), "URI");
+
+    if (list_suite.empty())
+        return _error->Error("Malformed entry %u in %s file %s (%s)", stanzaIdx, "sources", Fd.Name().c_str(), "Suite");
+
+    for (auto const &S : list_suite) {
+        SourceRecord rec = SourceRecord ();
+        rec.Deb822StanzaIdx = stanzaIdx;
+
+        if (!rec.SetURIs(list_uris))
+            return _error->Error("Malformed entry %u in %s file %s (%s)", stanzaIdx, "sources", Fd.Name().c_str(), "URI parse");
+
+        if (S.empty() == false && S[S.size() - 1] == '/') {
+            if (list_comp.empty() == false)
+                return _error->Error("Malformed entry %u in %s file %s (%s)", stanzaIdx, "sources", Fd.Name().c_str(), "absolute Suite Component");
+
+            rec.SourceFile = Fd.Name();
+            if (!rec.SetType(Type)) {
+                _error->Error("Unknown type %s", Type);
+                return false;
+            }
+
+            if (Enabled.empty() == false && StringToBool(Enabled) == false)
+                rec.Type |= SourcesList::Disabled;
+
+            rec.Dist = S;
+            rec.NumSections = 0;
+            rec.Sections = nullptr;
+            AddSourceNode(rec);
+         } else {
+            if (list_comp.empty())
+                return _error->Error("Malformed entry %u in %s file %s (%s)", stanzaIdx, "sources", Fd.Name().c_str(), "Component");
+
+            rec.SourceFile = Fd.Name();
+            if (!rec.SetType(Type)) {
+                _error->Error("Unknown type %s", Type);
+                return false;
+            }
+            if (Enabled.empty() == false && StringToBool(Enabled) == false)
+                rec.Type |= SourcesList::Disabled;
+
+            rec.Dist = S;
+            rec.NumSections = list_comp.size();
+            rec.Sections = new string[rec.NumSections];
+            std::copy(list_comp.begin(), list_comp.end(), rec.Sections);
+            AddSourceNode(rec);
+        }
+    }
+
+    return true;
+}
+
+
+bool SourcesList::ReadSourceDeb822(string listpath)
+{
+    FileFd Fd;
+    if (OpenConfigurationFileFd(listpath, Fd) == false)
+        return false;
+
+    pkgTagFile Sources(&Fd, pkgTagFile::SUPPORT_COMMENTS);
+    if (Fd.IsOpen() == false || Fd.Failed())
+        return _error->Error("Malformed stanza %u in source list %s (type)", 0, listpath.c_str());
+
+    // read step by step
+    pkgTagSection Tags;
+    for (guint i = 0; Sources.Step(Tags); i++) {
+        if(Tags.Exists("Types") == false)
+            return _error->Error("Malformed stanza %u in source list %s (type)", i, listpath.c_str());
+
+        for (auto const &type : FindMultiValue(Tags, "Types")) {
+            if (!ParseDeb822Stanza(type.c_str(), Tags, i, Fd))
+                return false;
+        }
+    }
+
+    return true;
+}
+
+bool SourcesList::ReadSourceLegacy(string listpath)
 {
-    //cout << "SourcesList::ReadSourcePart() "<< listpath  << endl;
     char buf[512];
     const char *p;
     ifstream ifs(listpath.c_str(), ios::in);
@@ -84,9 +207,8 @@ bool SourcesList::ReadSourcePart(string listpath)
         ifs.getline(buf, sizeof(buf));
 
         rec.SourceFile = listpath;
-        while (isspace(*p)) {
+        while (isspace(*p))
             p++;
-        }
 
         if (*p == '#') {
             rec.Type = Disabled;
@@ -131,7 +253,7 @@ bool SourcesList::ReadSourcePart(string listpath)
                 //return _error->Error("Syntax error in line %s", buf);
             }
         }
-#ifndef HAVE_RPM
+
         // check for absolute dist
         if (rec.Dist.empty() == false && rec.Dist[rec.Dist.size() - 1] == '/') {
             // make sure there's no section
@@ -144,7 +266,6 @@ bool SourcesList::ReadSourcePart(string listpath)
             AddSourceNode(rec);
             continue;
         }
-#endif
 
         const char *tmp = p;
         rec.NumSections = 0;
@@ -176,6 +297,15 @@ bool SourcesList::ReadSourcePart(string listpath)
     return record_ok;
 }
 
+bool SourcesList::ReadSourcePart(string listpath)
+{
+    if (g_str_has_suffix (listpath.c_str(), ".sources")) {
+        return ReadSourceDeb822(listpath);
+    } else {
+        return ReadSourceLegacy(listpath);
+    }
+}
+
 bool SourcesList::ReadSourceDir(string Dir)
 {
     //cout << "SourcesList::ReadSourceDir() " << Dir  << endl;
@@ -203,8 +333,9 @@ bool SourcesList::ReadSourceDir(string Dir)
             continue;
         }
 
-        // Only look at files ending in .list to skip .rpmnew etc files
-        if (strcmp(Ent->d_name + strlen(Ent->d_name) - 5, ".list") != 0) {
+        // Only look at files ending in .list and .sources, skip .dpkg-new/.bak/.save etc.
+        if (!g_str_has_suffix (Ent->d_name, ".list") &&
+            !g_str_has_suffix (Ent->d_name, ".sources")) {
             continue;
         }
 
@@ -253,11 +384,7 @@ bool SourcesList::ReadSources()
 SourcesList::SourceRecord *SourcesList::AddEmptySource()
 {
     SourceRecord rec;
-#ifdef HAVE_RPM
-    rec.Type = Rpm;
-#else
     rec.Type = Deb;
-#endif
     rec.VendorID = "";
     rec.SourceFile = _config->FindFile("Dir::Etc::sourcelist");
     rec.Dist = "";
@@ -309,6 +436,148 @@ void SourcesList::SwapSources( SourceRecord *&rec_one, SourceRecord *&rec_two )
     SourceRecords.erase( rec_n );
 }
 
+bool SourcesList::UpdateSourceLegacy(const string &filename)
+{
+    if (std::filesystem::path(filename).extension().string() != ".list") {
+        g_warning("Tried to update APT source file '%s' as legacy file, but filename has wrong extension.",
+            filename.c_str());
+        return false;
+    }
+
+    ofstream ofs(filename.c_str(), ios::out);
+    if (!ofs != 0) {
+        return false;
+    }
+
+    for (SourceRecord *sr : SourceRecords) {
+        if (filename != sr->SourceFile) {
+            continue;
+        }
+
+        string S;
+        if ((sr->Type & Comment) != 0) {
+            S = sr->Comment;
+        } else if (sr->PrimaryURI.empty() || sr->Dist.empty()) {
+            continue;
+        } else {
+            if ((sr->Type & Disabled) != 0)
+                S = "# ";
+
+            S += sr->GetType() + " ";
+
+            if (sr->VendorID.empty() == false)
+                S += "[" + sr->VendorID + "] ";
+
+            S += sr->PrimaryURI + " ";
+            S += sr->Dist + " ";
+
+            for (unsigned int J = 0; J < sr->NumSections; ++J) {
+                S += sr->Sections[J] + " ";
+            }
+        }
+
+        // remove extra linebreak from S, if it has any
+        if (!S.empty() && S[S.size() - 1] == '\n')
+            S.pop_back();
+        ofs << S << "\n";
+    }
+    ofs.close();
+
+    return true;
+}
+
+bool SourcesList::UpdateSourceDeb822(const std::string &filename)
+{
+    if (std::filesystem::path(filename).extension().string() != ".sources") {
+        g_warning("Tried to update APT source file '%s' in Deb822 format, but filename has wrong extension.",
+            filename.c_str());
+        return false;
+    }
+
+    Deb822File sf;
+    if (!sf.load(filename)) {
+        g_warning("Failed to load Deb822 file '%s': %s", filename.c_str(), sf.lastError().c_str());
+        return false;
+    }
+
+    std::set<uint> rmPendingStanzas;
+    for (SourceRecord *sr : SourceRecords) {
+        if (filename != sr->SourceFile)
+            continue;
+
+        // comments shouldn't exist for Deb822 files in this data structure,
+        // we parse them differently.
+        if ((sr->Type & Comment) != 0)
+            continue;
+
+        if (sr->PrimaryURI.empty() || sr->Dist.empty())
+            continue;
+
+        std::string components;
+        for (unsigned int J = 0; J < sr->NumSections; ++J)
+            components += sr->Sections[J] + " ";
+        if (!components.empty())
+            components.pop_back();
+
+        std::string uris;
+        for (const auto &uri : sr->URIs)
+            uris += uri + " ";
+        if (!uris.empty())
+            uris.pop_back();
+
+        const auto type = sr->GetType();
+
+        if (sf.getFieldValue(sr->Deb822StanzaIdx, "Types") != type ||
+            sf.getFieldValue(sr->Deb822StanzaIdx, "URIs") != uris ||
+            sf.getFieldValue(sr->Deb822StanzaIdx, "Components") != components ||
+            sf.getFieldValue(sr->Deb822StanzaIdx, "Suites") != sr->Dist) {
+            // The new Deb822 sources do not fit well on the existing data model and concept of
+            // what a "source" is, so we rewrite the file to make it match a "one stanza per source"
+            // scheme like what existed in legacy files.
+            // FIXME: In the long run, we should reconsider what a repository source is and adjust the internal
+            // data model, as rewriting the file like this is a really ugly hack.
+
+            // mark the old stanza for deletion and create a new one that we will edit
+            rmPendingStanzas.insert(sr->Deb822StanzaIdx);
+            sr->Deb822StanzaIdx = sf.duplicateStanza(sr->Deb822StanzaIdx);
+        }
+
+        sf.updateField(sr->Deb822StanzaIdx, "Types", type);
+        sf.updateField(sr->Deb822StanzaIdx, "URIs", uris);
+        sf.updateField(sr->Deb822StanzaIdx, "Suites", sr->Dist);
+        sf.updateField(sr->Deb822StanzaIdx, "Components", components);
+
+        if ((sr->Type & Disabled) != 0)
+            sf.updateField(sr->Deb822StanzaIdx, "Enabled", "no");
+        else
+            sf.deleteField(sr->Deb822StanzaIdx, "Enabled");
+    }
+
+    // delete any stanzas marked for removal, in descending order to avoid index shifting
+    std::vector<uint> sortedRmStanzas(rmPendingStanzas.begin(), rmPendingStanzas.end());
+    std::sort(sortedRmStanzas.rbegin(), sortedRmStanzas.rend());
+    for (uint rmIdx : sortedRmStanzas)
+        sf.deleteStanza(rmIdx);
+
+    if (!sf.save(filename)) {
+        g_warning("Failed to save Deb822 file '%s': %s", filename.c_str(), sf.lastError().c_str());
+        return false;
+    }
+
+    // remove all records from this file
+    for (auto it = SourceRecords.begin(); it != SourceRecords.end();) {
+        if ((*it)->SourceFile == filename) {
+            delete *it;
+            it = SourceRecords.erase(it);
+        } else {
+            ++it;
+        }
+    }
+
+    // reload the updated data
+    return ReadSourceDeb822(filename);
+}
+
 bool SourcesList::UpdateSources()
 {
     list<string> filenames;
@@ -322,41 +591,21 @@ bool SourcesList::UpdateSources()
     filenames.unique();
 
     for (const string &filename : filenames) {
-        ofstream ofs(filename.c_str(), ios::out);
-        if (!ofs != 0) {
-            return false;
+        const auto fileExt = std::filesystem::path(filename).extension().string();
+        if (fileExt == ".sources") {
+            if (!UpdateSourceDeb822(filename))
+                return false;
+
+        } else if (fileExt == ".list") {
+            if (!UpdateSourceLegacy(filename))
+                return false;
+
+        } else {
+            g_warning("Tried to update APT source file '%s', but could not determine file type.",
+                filename.c_str());
         }
-
-        for (SourceRecord *sr : SourceRecords) {
-            if (filename != sr->SourceFile) {
-                continue;
-            }
-
-            string S;
-            if ((sr->Type & Comment) != 0) {
-                S = sr->Comment;
-            } else if (sr->URI.empty() || sr->Dist.empty()) {
-                continue;
-            } else {
-                if ((sr->Type & Disabled) != 0)
-                    S = "# ";
-
-                S += sr->GetType() + " ";
-
-                if (sr->VendorID.empty() == false)
-                    S += "[" + sr->VendorID + "] ";
-
-                S += sr->URI + " ";
-                S += sr->Dist + " ";
-
-                for (unsigned int J = 0; J < sr->NumSections; ++J) {
-                    S += sr->Sections[J] + " ";
-                }
-            }
-            ofs << S << endl;
-        }
-        ofs.close();
     }
+
     return true;
 }
 
@@ -366,23 +615,10 @@ bool SourcesList::SourceRecord::SetType(string S)
         Type |= Deb;
     } else if (S == "deb-src") {
         Type |= DebSrc;
-    } else if (S == "rpm") {
-        Type |= Rpm;
-    } else if (S == "rpm-src") {
-        Type |= RpmSrc;
-    } else if (S == "rpm-dir") {
-        Type |= RpmDir;
-    } else if (S == "rpm-src-dir") {
-        Type |= RpmSrcDir;
-    } else if (S == "repomd") {
-        Type |= Repomd;
-    } else if (S == "repomd-src") {
-        Type |= RepomdSrc;
     } else {
         return false;
     }
 
-    //cout << S << " settype " << (Type | Repomd) << endl;
     return true;
 }
 
@@ -392,52 +628,55 @@ string SourcesList::SourceRecord::GetType()
         return "deb";
     } else if ((Type & DebSrc) != 0) {
         return "deb-src";
-    } else if ((Type & Rpm) != 0) {
-        return "rpm";
-    } else if ((Type & RpmSrc) != 0) {
-        return "rpm-src";
-    } else if ((Type & RpmDir) != 0) {
-        return "rpm-dir";
-    } else if ((Type & RpmSrcDir) != 0) {
-        return "rpm-src-dir";
-    } else if ((Type & Repomd) != 0) {
-        return "repomd";
-    } else if ((Type & RepomdSrc) != 0) {
-        return "repomd-src";
     }
 
-    //cout << "type " << (Type & Repomd) << endl;
     return "unknown";
 }
 
-bool SourcesList::SourceRecord::SetURI(string S)
+static bool FixupURI(string &URI)
 {
-    if (S.empty() == true) {
+    if (URI.empty() == true)
         return false;
-    }
-    if (S.find(':') == string::npos) {
+
+    if (URI.find(':') == string::npos)
         return false;
-    }
 
-    S = SubstVar(S, "$(ARCH)", _config->Find("APT::Architecture"));
-    S = SubstVar(S, "$(VERSION)", _config->Find("APT::DistroVersion"));
-    URI = S;
+    URI = ::URI{SubstVar(URI, "$(ARCH)", _config->Find("APT::Architecture"))};
 
-    // append a / to the end if one is not already there
-    if (URI[URI.size() - 1] != '/') {
-        URI += '/';
-    }
+    // Make sure that the URI is / postfixed
+    if (URI.back() != '/')
+        URI.push_back('/');
 
     return true;
 }
 
-string SourcesList::SourceRecord::joinedSections()
+bool SourcesList::SourceRecord::SetURI(string S)
+{
+    PrimaryURI = S;
+    return ::FixupURI(PrimaryURI);
+}
+
+bool SourcesList::SourceRecord::SetURIs(const std::vector<std::string> &newURIs)
+{
+    bool ret = true;
+    URIs = newURIs;
+
+    for (auto &uri : URIs) {
+        if (!::FixupURI(uri))
+            ret = false;
+    }
+    PrimaryURI = URIs.empty()? "" : URIs[0];
+
+    return ret;
+}
+
+string SourcesList::SourceRecord::joinedSections(const std::string &separator)
 {
     string ret;
     for (unsigned int i = 0; i < NumSections; ++i) {
         ret += Sections[i];
         if (i + 1 < NumSections) {
-            ret += " ";
+            ret += separator;
         }
     }
     return ret;
@@ -446,7 +685,7 @@ string SourcesList::SourceRecord::joinedSections()
 string SourcesList::SourceRecord::niceName()
 {
     string ret;
-    if (starts_with(URI, "cdrom")) {
+    if (starts_with(PrimaryURI, "cdrom")) {
         ret = "Disc ";
     }
 
@@ -473,11 +712,11 @@ string SourcesList::SourceRecord::niceName()
     }
 
     std::string uri_info;
-    size_t schema_pos = URI.find("://");
+    size_t schema_pos = PrimaryURI.find("://");
     if (schema_pos == std::string::npos) {
-        uri_info = URI;
+        uri_info = PrimaryURI;
     } else {
-        uri_info = URI.substr(schema_pos + 3);
+        uri_info = PrimaryURI.substr(schema_pos + 3);
         if (uri_info.back() == '/')
             uri_info.pop_back();
     }
@@ -496,11 +735,10 @@ string SourcesList::SourceRecord::repoId()
 {
     string ret;
     ret = SourceFile;
-    ret += ":" + GetType();
-    ret += VendorID + " ";
-    ret += URI + " ";
-    ret += Dist + " ";
-    ret += joinedSections();
+    ret += ":" + GetType() + ":";
+    ret += PrimaryURI + ":";
+    ret += Dist + ":";
+    ret += joinedSections(",");
     return ret;
 }
 
@@ -519,7 +757,8 @@ SourcesList::SourceRecord &SourcesList::SourceRecord::operator=(const SourceReco
     // Needed for a proper deep copy of the record; uses the string operator= to properly copy the strings
     Type = rhs.Type;
     VendorID = rhs.VendorID;
-    URI = rhs.URI;
+    PrimaryURI = rhs.PrimaryURI;
+    URIs = rhs.URIs;
     Dist = rhs.Dist;
     Sections = new string[rhs.NumSections];
     for (unsigned int I = 0; I < rhs.NumSections; ++I) {
@@ -528,6 +767,7 @@ SourcesList::SourceRecord &SourcesList::SourceRecord::operator=(const SourceReco
     NumSections = rhs.NumSections;
     Comment = rhs.Comment;
     SourceFile = rhs.SourceFile;
+    Deb822StanzaIdx = rhs.Deb822StanzaIdx;
 
     return *this;
 }
@@ -644,28 +884,10 @@ ostream &operator<<(ostream &os, const SourcesList::SourceRecord &rec)
     if ((rec.Type & SourcesList::DebSrc) != 0) {
         os << "DebSrc";
     }
-    if ((rec.Type & SourcesList::Rpm) != 0) {
-        os << "Rpm";
-    }
-    if ((rec.Type & SourcesList::RpmSrc) != 0) {
-        os << "RpmSrc";
-    }
-    if ((rec.Type & SourcesList::RpmDir) != 0) {
-        os << "RpmDir";
-    }
-    if ((rec.Type & SourcesList::RpmSrcDir) != 0) {
-        os << "RpmSrcDir";
-    }
-    if ((rec.Type & SourcesList::Repomd) != 0) {
-        os << "Repomd";
-    }
-    if ((rec.Type & SourcesList::RepomdSrc) != 0) {
-        os << "RepomdSrc";
-    }
     os << endl;
     os << "SourceFile: " << rec.SourceFile << endl;
     os << "VendorID: " << rec.VendorID << endl;
-    os << "URI: " << rec.URI << endl;
+    os << "URI: " << rec.PrimaryURI << endl;
     os << "Dist: " << rec.Dist << endl;
     os << "Section(s):" << endl;
 #if 0
