@@ -57,6 +57,7 @@ G_BEGIN_DECLS
  * @PK_CLIENT_ERROR_INVALID_FILE: the file is invalid
  * @PK_CLIENT_ERROR_NOT_SUPPORTED: the action is not supported
  * @PK_CLIENT_ERROR_DECLINED_SIMULATION: the simulation was declined by the user
+ * @PK_CLIENT_ERROR_DECLINED_INTERACTION: the user declined interaction on the task
  * @PK_CLIENT_ERROR_LAST:
  *
  * Errors that can be thrown
@@ -73,6 +74,7 @@ typedef enum
 	PK_CLIENT_ERROR_INVALID_FILE,
 	PK_CLIENT_ERROR_NOT_SUPPORTED,
 	PK_CLIENT_ERROR_DECLINED_SIMULATION,
+	PK_CLIENT_ERROR_DECLINED_INTERACTION,
 	/* we define this so we can punt the PkErrorEnums here at offset 0xff */
 	PK_CLIENT_ERROR_LAST
 } PkClientError;
@@ -412,6 +414,9 @@ void		 pk_client_get_progress_async 		(PkClient		*client,
 							 GAsyncReadyCallback	 callback_ready,
 							 gpointer		 user_data);
 
+gboolean	pk_client_create_helper_argv_envp	(gchar 			***argv,
+							 gchar			***envp_out);
+
 /* getters and setters */
 void		 pk_client_set_locale			(PkClient		*client,
 							 const gchar		*locale);
@@ -426,6 +431,9 @@ gboolean	 pk_client_get_idle			(PkClient		*client);
 void		 pk_client_set_cache_age		(PkClient		*client,
 							 guint			 cache_age);
 guint		 pk_client_get_cache_age		(PkClient		*client);
+void		 pk_client_set_details_with_deps_size	(PkClient		*client,
+							 gboolean		 details_with_deps_size);
+gboolean	 pk_client_get_details_with_deps_size	(PkClient		*client);
 
 G_END_DECLS
 
