@@ -62,7 +62,7 @@ enum {
 
 G_DEFINE_TYPE (PkMediaChangeRequired, pk_media_change_required, PK_TYPE_SOURCE)
 
-/**
+/*
  * pk_media_change_required_get_property:
  **/
 static void
@@ -87,7 +87,7 @@ pk_media_change_required_get_property (GObject *object, guint prop_id, GValue *v
 	}
 }
 
-/**
+/*
  * pk_media_change_required_set_property:
  **/
 static void
@@ -114,7 +114,7 @@ pk_media_change_required_set_property (GObject *object, guint prop_id, const GVa
 	}
 }
 
-/**
+/*
  * pk_media_change_required_class_init:
  **/
 static void
@@ -133,7 +133,7 @@ pk_media_change_required_class_init (PkMediaChangeRequiredClass *klass)
 	 */
 	pspec = g_param_spec_enum ("media-type", NULL, NULL,
 				   PK_TYPE_MEDIA_TYPE_ENUM, PK_MEDIA_TYPE_ENUM_UNKNOWN,
-				   G_PARAM_READWRITE);
+				   G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 	g_object_class_install_property (object_class, PROP_MEDIA_TYPE, pspec);
 
 	/**
@@ -143,7 +143,7 @@ pk_media_change_required_class_init (PkMediaChangeRequiredClass *klass)
 	 */
 	pspec = g_param_spec_string ("media-id", NULL, NULL,
 				     NULL,
-				     G_PARAM_READWRITE);
+				     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 	g_object_class_install_property (object_class, PROP_MEDIA_ID, pspec);
 
 	/**
@@ -153,13 +153,13 @@ pk_media_change_required_class_init (PkMediaChangeRequiredClass *klass)
 	 */
 	pspec = g_param_spec_string ("media-text", NULL, NULL,
 				     NULL,
-				     G_PARAM_READWRITE);
+				     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 	g_object_class_install_property (object_class, PROP_MEDIA_TEXT, pspec);
 
 	g_type_class_add_private (klass, sizeof (PkMediaChangeRequiredPrivate));
 }
 
-/**
+/*
  * pk_media_change_required_init:
  **/
 static void
@@ -168,7 +168,7 @@ pk_media_change_required_init (PkMediaChangeRequired *media_change_required)
 	media_change_required->priv = PK_MEDIA_CHANGE_REQUIRED_GET_PRIVATE (media_change_required);
 }
 
-/**
+/*
  * pk_media_change_required_finalize:
  **/
 static void
@@ -186,7 +186,7 @@ pk_media_change_required_finalize (GObject *object)
 /**
  * pk_media_change_required_new:
  *
- * Return value: a new PkMediaChangeRequired object.
+ * Return value: a new #PkMediaChangeRequired object.
  *
  * Since: 0.5.4
  **/
