@@ -32,6 +32,7 @@
 #include <packagekit-glib2/pk-enum.h>
 #include <packagekit-glib2/pk-package-id.h>
 #include <packagekit-glib2/pk-progress.h>
+#include <packagekit-glib2/pk-progress-private.h>
 
 static void     pk_progress_dispose	(GObject     *object);
 static void     pk_progress_finalize	(GObject     *object);
@@ -59,6 +60,8 @@ struct _PkProgressPrivate
 	gchar				*sender;
 	PkItemProgress			*item_progress;
 	PkPackage			*package;
+	PkProgressCallback		 callback;
+	gpointer			 callback_user_data;
 };
 
 enum {
@@ -150,6 +153,17 @@ pk_progress_get_property (GObject *object, guint prop_id, GValue *value, GParamS
 	}
 }
 
+static inline void
+pk_progress_invoke_callback (PkProgress *progress, PkProgressType type)
+{
+	PkProgressPrivate *priv = pk_progress_get_instance_private (progress);
+
+	g_assert (PK_IS_PROGRESS (progress));
+
+	if (priv->callback)
+		priv->callback (progress, type, priv->callback_user_data);
+}
+
 /**
  * pk_progress_set_package_id:
  * @progress: a valid #PkProgress instance
@@ -182,6 +196,7 @@ pk_progress_set_package_id (PkProgress *progress, const gchar *package_id)
 	g_free (priv->package_id);
 	priv->package_id = g_strdup (package_id);
 	g_object_notify_by_pspec (G_OBJECT(progress), obj_properties[PROP_PACKAGE_ID]);
+	pk_progress_invoke_callback (progress, PK_PROGRESS_TYPE_PACKAGE_ID);
 
 	return TRUE;
 }
@@ -227,6 +242,7 @@ pk_progress_set_item_progress (PkProgress *progress,
 
 	if (g_set_object (&priv->item_progress, item_progress)) {
 		g_object_notify_by_pspec (G_OBJECT(progress), obj_properties[PROP_ITEM_PROGRESS]);
+		pk_progress_invoke_callback (progress, PK_PROGRESS_TYPE_ITEM_PROGRESS);
 		return TRUE;
 	}
 
@@ -279,6 +295,7 @@ pk_progress_set_transaction_id (PkProgress *progress, const gchar *transaction_i
 	g_free (priv->transaction_id);
 	priv->transaction_id = g_strdup (transaction_id);
 	g_object_notify_by_pspec (G_OBJECT(progress), obj_properties[PROP_TRANSACTION_ID]);
+	pk_progress_invoke_callback (progress, PK_PROGRESS_TYPE_TRANSACTION_ID);
 
 	return TRUE;
 }
@@ -328,6 +345,7 @@ pk_progress_set_percentage (PkProgress *progress, gint percentage)
 	/* new value */
 	priv->percentage = percentage;
 	g_object_notify_by_pspec (G_OBJECT(progress), obj_properties[PROP_PERCENTAGE]);
+	pk_progress_invoke_callback (progress, PK_PROGRESS_TYPE_PERCENTAGE);
 
 	return TRUE;
 }
@@ -377,6 +395,7 @@ pk_progress_set_status (PkProgress *progress, PkStatusEnum status)
 	/* new value */
 	priv->status = status;
 	g_object_notify_by_pspec (G_OBJECT(progress), obj_properties[PROP_STATUS]);
+	pk_progress_invoke_callback (progress, PK_PROGRESS_TYPE_STATUS);
 
 	return TRUE;
 }
@@ -431,6 +450,7 @@ pk_progress_set_role (PkProgress *progress, PkRoleEnum role)
 	priv->role = role;
 	g_debug ("role now %s", pk_role_enum_to_string (role));
 	g_object_notify_by_pspec (G_OBJECT(progress), obj_properties[PROP_ROLE]);
+	pk_progress_invoke_callback (progress, PK_PROGRESS_TYPE_ROLE);
 
 	return TRUE;
 }
@@ -480,6 +500,7 @@ pk_progress_set_allow_cancel (PkProgress *progress, gboolean allow_cancel)
 	/* new value */
 	priv->allow_cancel = allow_cancel;
 	g_object_notify_by_pspec (G_OBJECT(progress), obj_properties[PROP_ALLOW_CANCEL]);
+	pk_progress_invoke_callback (progress, PK_PROGRESS_TYPE_ALLOW_CANCEL);
 
 	return TRUE;
 }
@@ -529,6 +550,7 @@ pk_progress_set_caller_active (PkProgress *progress, gboolean caller_active)
 	/* new value */
 	priv->caller_active = caller_active;
 	g_object_notify_by_pspec (G_OBJECT(progress), obj_properties[PROP_CALLER_ACTIVE]);
+	pk_progress_invoke_callback (progress, PK_PROGRESS_TYPE_CALLER_ACTIVE);
 
 	return TRUE;
 }
@@ -578,6 +600,7 @@ pk_progress_set_elapsed_time (PkProgress *progress, guint elapsed_time)
 	/* new value */
 	priv->elapsed_time = elapsed_time;
 	g_object_notify_by_pspec (G_OBJECT(progress), obj_properties[PROP_ELAPSED_TIME]);
+	pk_progress_invoke_callback (progress, PK_PROGRESS_TYPE_ELAPSED_TIME);
 
 	return TRUE;
 }
@@ -627,6 +650,7 @@ pk_progress_set_remaining_time (PkProgress *progress, guint remaining_time)
 	/* new value */
 	priv->remaining_time = remaining_time;
 	g_object_notify_by_pspec (G_OBJECT(progress), obj_properties[PROP_REMAINING_TIME]);
+	pk_progress_invoke_callback (progress, PK_PROGRESS_TYPE_REMAINING_TIME);
 
 	return TRUE;
 }
@@ -676,6 +700,7 @@ pk_progress_set_speed (PkProgress *progress, guint speed)
 	/* new value */
 	priv->speed = speed;
 	g_object_notify_by_pspec (G_OBJECT(progress), obj_properties[PROP_SPEED]);
+	pk_progress_invoke_callback (progress, PK_PROGRESS_TYPE_SPEED);
 
 	return TRUE;
 }
@@ -725,6 +750,7 @@ pk_progress_set_download_size_remaining (PkProgress *progress, guint64 download_
 	/* new value */
 	priv->download_size_remaining = download_size_remaining;
 	g_object_notify_by_pspec (G_OBJECT(progress), obj_properties[PROP_DOWNLOAD_SIZE_REMAINING]);
+	pk_progress_invoke_callback (progress, PK_PROGRESS_TYPE_DOWNLOAD_SIZE_REMAINING);
 
 	return TRUE;
 }
@@ -774,6 +800,7 @@ pk_progress_set_transaction_flags (PkProgress *progress, guint64 transaction_fla
 	/* new value */
 	priv->transaction_flags = transaction_flags;
 	g_object_notify_by_pspec (G_OBJECT(progress), obj_properties[PROP_TRANSACTION_FLAGS]);
+	pk_progress_invoke_callback (progress, PK_PROGRESS_TYPE_TRANSACTION_FLAGS);
 
 	return TRUE;
 }
@@ -823,6 +850,7 @@ pk_progress_set_uid (PkProgress *progress, guint uid)
 	/* new value */
 	priv->uid = uid;
 	g_object_notify_by_pspec (G_OBJECT(progress), obj_properties[PROP_UID]);
+	pk_progress_invoke_callback (progress, PK_PROGRESS_TYPE_UID);
 
 	return TRUE;
 }
@@ -873,6 +901,7 @@ pk_progress_set_sender (PkProgress *progress, const gchar *bus_name)
 	g_free (priv->sender);
 	priv->sender = g_strdup (bus_name);
 	g_object_notify_by_pspec (G_OBJECT(progress), obj_properties[PROP_SENDER]);
+	pk_progress_invoke_callback (progress, PK_PROGRESS_TYPE_SENDER);
 
 	return TRUE;
 }
@@ -917,6 +946,7 @@ pk_progress_set_package (PkProgress *progress, PkPackage *package)
 
 	if (g_set_object (&priv->package, package)) {
 		g_object_notify_by_pspec (G_OBJECT(progress), obj_properties[PROP_PACKAGE]);
+		pk_progress_invoke_callback (progress, PK_PROGRESS_TYPE_PACKAGE);
 		return TRUE;
 	}
 
@@ -943,6 +973,29 @@ pk_progress_get_package (PkProgress *progress)
 	return priv->package;
 }
 
+/**
+ * pk_progress_new_with_callback:
+ * @callback: (scope notified): the function to run when the progress changes
+ * @user_data: data to pass to @callback
+ *
+ * Create a progress with a callback function.
+ *
+ * Returns: (transfer full): a new #PkProgress
+ **/
+PkProgress *
+pk_progress_new_with_callback (PkProgressCallback callback, gpointer user_data)
+{
+	PkProgress *progress;
+	PkProgressPrivate *priv;
+
+	progress = pk_progress_new ();
+	priv = pk_progress_get_instance_private (progress);
+	priv->callback = callback;
+	priv->callback_user_data = user_data;
+
+	return progress;
+}
+
 /*
  * pk_progress_set_property:
  **/
@@ -991,6 +1044,15 @@ pk_progress_set_property (GObject *object, guint prop_id, const GValue *value, G
 	case PROP_ITEM_PROGRESS:
 		pk_progress_set_item_progress (progress, g_value_get_object (value));
 		break;
+	case PROP_SENDER:
+		pk_progress_set_sender (progress, g_value_get_string (value));
+		break;
+	case PROP_DOWNLOAD_SIZE_REMAINING:
+		pk_progress_set_download_size_remaining (progress, g_value_get_uint64 (value));
+		break;
+	case PROP_TRANSACTION_FLAGS:
+		pk_progress_set_transaction_flags (progress, g_value_get_uint64 (value));
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
