@@ -72,7 +72,7 @@ enum {
 
 G_DEFINE_TYPE (PkRepoSignatureRequired, pk_repo_signature_required, PK_TYPE_SOURCE)
 
-/**
+/*
  * pk_repo_signature_required_get_property:
  **/
 static void
@@ -112,7 +112,7 @@ pk_repo_signature_required_get_property (GObject *object, guint prop_id, GValue
 	}
 }
 
-/**
+/*
  * pk_repo_signature_required_set_property:
  **/
 static void
@@ -159,7 +159,7 @@ pk_repo_signature_required_set_property (GObject *object, guint prop_id, const G
 	}
 }
 
-/**
+/*
  * pk_repo_signature_required_class_init:
  **/
 static void
@@ -178,7 +178,7 @@ pk_repo_signature_required_class_init (PkRepoSignatureRequiredClass *klass)
 	 */
 	pspec = g_param_spec_string ("package-id", NULL, NULL,
 				     NULL,
-				     G_PARAM_READWRITE);
+				     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 	g_object_class_install_property (object_class, PROP_PACKAGE_ID, pspec);
 
 	/**
@@ -188,7 +188,7 @@ pk_repo_signature_required_class_init (PkRepoSignatureRequiredClass *klass)
 	 */
 	pspec = g_param_spec_string ("repository-name", NULL, NULL,
 				     NULL,
-				     G_PARAM_READWRITE);
+				     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 	g_object_class_install_property (object_class, PROP_REPOSITORY_NAME, pspec);
 
 	/**
@@ -198,7 +198,7 @@ pk_repo_signature_required_class_init (PkRepoSignatureRequiredClass *klass)
 	 */
 	pspec = g_param_spec_string ("key-url", NULL, NULL,
 				     NULL,
-				     G_PARAM_READWRITE);
+				     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 	g_object_class_install_property (object_class, PROP_KEY_URL, pspec);
 
 	/**
@@ -208,7 +208,7 @@ pk_repo_signature_required_class_init (PkRepoSignatureRequiredClass *klass)
 	 */
 	pspec = g_param_spec_string ("key-userid", NULL, NULL,
 				     NULL,
-				     G_PARAM_READWRITE);
+				     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 	g_object_class_install_property (object_class, PROP_KEY_USERID, pspec);
 
 	/**
@@ -218,7 +218,7 @@ pk_repo_signature_required_class_init (PkRepoSignatureRequiredClass *klass)
 	 */
 	pspec = g_param_spec_string ("key-id", NULL, NULL,
 				     NULL,
-				     G_PARAM_READWRITE);
+				     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 	g_object_class_install_property (object_class, PROP_KEY_ID, pspec);
 
 	/**
@@ -228,7 +228,7 @@ pk_repo_signature_required_class_init (PkRepoSignatureRequiredClass *klass)
 	 */
 	pspec = g_param_spec_string ("key-fingerprint", NULL, NULL,
 				     NULL,
-				     G_PARAM_READWRITE);
+				     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 	g_object_class_install_property (object_class, PROP_KEY_FINGERPRINT, pspec);
 
 	/**
@@ -238,7 +238,7 @@ pk_repo_signature_required_class_init (PkRepoSignatureRequiredClass *klass)
 	 */
 	pspec = g_param_spec_string ("key-timestamp", NULL, NULL,
 				     NULL,
-				     G_PARAM_READWRITE);
+				     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 	g_object_class_install_property (object_class, PROP_KEY_TIMESTAMP, pspec);
 
 	/**
@@ -248,13 +248,13 @@ pk_repo_signature_required_class_init (PkRepoSignatureRequiredClass *klass)
 	 */
 	pspec = g_param_spec_enum ("type", NULL, NULL,
 				   PK_TYPE_SIG_TYPE_ENUM, PK_SIGTYPE_ENUM_UNKNOWN,
-				   G_PARAM_READWRITE);
+				   G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 	g_object_class_install_property (object_class, PROP_TYPE, pspec);
 
 	g_type_class_add_private (klass, sizeof (PkRepoSignatureRequiredPrivate));
 }
 
-/**
+/*
  * pk_repo_signature_required_init:
  **/
 static void
@@ -263,7 +263,7 @@ pk_repo_signature_required_init (PkRepoSignatureRequired *repo_signature_require
 	repo_signature_required->priv = PK_REPO_SIGNATURE_REQUIRED_GET_PRIVATE (repo_signature_required);
 }
 
-/**
+/*
  * pk_repo_signature_required_finalize:
  **/
 static void
@@ -286,7 +286,7 @@ pk_repo_signature_required_finalize (GObject *object)
 /**
  * pk_repo_signature_required_new:
  *
- * Return value: a new PkRepoSignatureRequired object.
+ * Return value: a new #PkRepoSignatureRequired object.
  *
  * Since: 0.5.4
  **/
