@@ -444,7 +444,7 @@ pk_backend_job_set_cache_age (PkBackendJob *job, guint cache_age)
 	if (cache_age != G_MAXUINT && cache_age > cache_age_offset)
 		cache_age -= cache_age_offset;
 
-	g_debug ("cache-age changed to %u", cache_age);
+	g_debug ("cache-age changed to %u seconds", cache_age);
 	job->priv->cache_age = cache_age;
 }
 
