@@ -85,8 +85,6 @@ void		 pk_transaction_set_state			(PkTransaction	*transaction,
 const gchar	*pk_transaction_state_to_string			(PkTransactionState state);
 const gchar	*pk_transaction_get_tid				(PkTransaction	*transaction);
 gboolean	 pk_transaction_is_exclusive			(PkTransaction	*transaction);
-void		 pk_transaction_set_supported_roles		(PkTransaction	*transaction,
-								 GPtrArray	*plugins);
 gboolean	 pk_transaction_is_finished_with_lock_required	(PkTransaction *transaction);
 void		 pk_transaction_reset_after_lock_error		(PkTransaction *transaction);
 void		 pk_transaction_make_exclusive			(PkTransaction *transaction);
